package com.xinelu.manage.service.signpatientinformed;

import com.xinelu.manage.domain.signpatientinformed.SignPatientInformed;
import java.util.List;

/**
 * 签约知情同意书信息Service接口
 *
 * @author xinelu
 * @date 2024-02-27
 */
public interface ISignPatientInformedService {
    /**
     * 查询签约知情同意书信息
     *
     * @param id 签约知情同意书信息主键
     * @return 签约知情同意书信息
     */
    public SignPatientInformed selectSignPatientInformedById(Long id);

    /**
     * 查询签约知情同意书信息列表
     *
     * @param signPatientInformed 签约知情同意书信息
     * @return 签约知情同意书信息集合
     */
    public List<SignPatientInformed> selectSignPatientInformedList(SignPatientInformed signPatientInformed);

    /**
     * 新增签约知情同意书信息
     *
     * @param signPatientInformed 签约知情同意书信息
     * @return 结果
     */
    public int insertSignPatientInformed(SignPatientInformed signPatientInformed);

    /**
     * 修改签约知情同意书信息
     *
     * @param signPatientInformed 签约知情同意书信息
     * @return 结果
     */
    public int updateSignPatientInformed(SignPatientInformed signPatientInformed);

    /**
     * 批量删除签约知情同意书信息
     *
     * @param ids 需要删除的签约知情同意书信息主键集合
     * @return 结果
     */
    public int deleteSignPatientInformedByIds(Long[] ids);

    /**
     * 删除签约知情同意书信息信息
     *
     * @param id 签约知情同意书信息主键
     * @return 结果
     */
    public int deleteSignPatientInformedById(Long id);


}
